'''
Created on 22.3.2012

@author: matej
'''
import unittest2 as unittest
import tap
import logging
import subprocess
import os.path

class Test(unittest.TestCase):
    def test_simple_statement(self):
        name = "simple pass statement"
        result = tap.PASS
        expected = "ok - %s" % name
        observed = tap.TAPGenerator().format_TAP_msg(result, name)
        self.assertEqual(expected, observed)

    def test_skip_statement(self):
        name = "simple skip statement"
        result = tap.SKIP
        expected = "ok - %s\t# %s " % (name, "SKIP")
        observed = tap.TAPGenerator().format_TAP_msg(result, name)
        self.assertEqual(expected, observed)

    def test_fail_statement(self):
        name = "simple fail statement"
        result = tap.FAIL
        expected = "not ok - %s\t# %s " % (name, "FAIL")
        observed = tap.TAPGenerator().format_TAP_msg(result, name)
        self.assertEqual(expected, observed)

    def test_error_statement(self):
        name = "simple error statement"
        result = tap.ERROR
        expected = "not ok - %s\t# %s " % (name, "ERROR")
        observed = tap.TAPGenerator().format_TAP_msg(result, name)
        self.assertEqual(expected, observed)

    def test_statement_with_data(self):
        name = "complex statement with data"
        result = tap.PASS
        expected = "ok - %s\n  ---\n  justification: |-\n" % name \
            + "    very hungry\n    dog ate my homework\n  reason: 42\n  ..."
        observed = tap.TAPGenerator().format_TAP_msg(result, name, None, {
           "reason": 42,
           "justification": "very hungry\ndog ate my homework"
        })
        self.assertEqual(expected, observed)

    def test_generate_TAP(self):
        logging.debug("current directory = %s" % os.path.realpath(os.path.curdir))
        cmd = subprocess.Popen(['python', 'generate_TAP.py', './test/data/results.json'],
                   bufsize= -1, close_fds=True, stdout=subprocess.PIPE)
        (stdoutdata, stderr) = cmd.communicate()
        if(cmd.returncode == 0):
            exp_file = open("test/data/results.tap", "r")
            expected = exp_file.read()
            self.assertEqual(expected, stdoutdata, "generated TAP from JSON piglit results.")



if __name__ == "__main__":
    unittest.main()



'''
Although this looks an unittest module, it is not, as it doesn't test
the unittest_TAP. It is meant to be used only as an example of unittest_TAP use.
'''
import unittest_TAP


class Test(unittest_TAP.TestCase):
    def testRunningTest(self):
        """
        Empty test just to see that it is run.
        """
        self.assertTrue(True)

    @unittest_TAP.skip("demonstarting skipping")
    def testSkippingTest(self):
        """
        This test is to be skipped.
        """
        self.assertTrue(True)

    def testErrorTest(self):
        """
        This test ends in an error.
        """
        with self.assertRaises(IOError):
            raise ValueError

    def testFailedTest(self):
        """
        This test fails.
        """
        self.assertTrue(False)

    def testRunTestSuite(self):
        raise NotImplementedError("testRunTestSuite not implemented yet.")

if __name__ == "__main__":
    unittest_TAP.main()



# -*- coding: utf-8 -*-
#Copyright (C) 2012 Red Hat, Inc.
#
#Permission is hereby granted, free of charge, to any person obtaining a copy of
#this software and associated documentation files (the "Software"), to deal in
#the Software without restriction, including without limitation the rights to
#use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
#of the Software, and to permit persons to whom the Software is furnished to do
#so, subject to the following conditions:
#
#The above copyright notice and this permission notice shall be included in all
#copies or substantial portions of the Software.
#
#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
#OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
#SOFTWARE.
import yamlish
import logging

PASS = 0
SKIP = 1
TBD = 2  #IGNORE:W0511
FAIL = 3
ERROR = 4

__docformat__ = 'reStructuredText'
__version__ = "0.2"
__author__ = "Matej Cepl <mcepl_at_redhat_dot_com>"

class TAPGenerator(object):
    def __init__(self):
        self.translate_msg = {
            PASS: self._pass,
            SKIP: self._skip,
            TBD: self._tbd,
            FAIL: self._fail,
            ERROR: self._error,
        }

    def _indent(self, instr, indent="\t"):
        return "\n".join(indent + line
                     for line in instr.split("\n"))

    def _format_string(self, result, reason, name, data):
        out_str = result
        if name is not None:
            out_str += " - %s" % name
        if reason:
            out_str += "\t# %s" % reason
        if data:
            logging.debug("data:\n%s", data)
            yamlish_str = yamlish.dumps(data)
            logging.debug("yamlish_str:\n%s", yamlish_str)
            line_str = self._indent(yamlish_str, "  ")
            logging.debug("line_str:\n%s", line_str)
            out_str += "\n%s" % line_str.rstrip()
        return out_str

    def _pass(self, name, desc, data):
        return self._format_string("ok", desc, name, data)

    def _skip(self, name, desc, data):
        skip_msg = "SKIP"
        if desc is not None:
            skip_msg += " " + desc
        return self._format_string("ok", skip_msg, name, data)

    def _tbd(self, name, desc, data):
        return self._format_string("todo", desc, name, data)

    def _fail(self, name, desc, data):
        return self._format_string("not ok", "FAIL " + desc, name, data)

    def _error(self, name, desc, data):
        return self._format_string("not ok", "ERROR " + desc, name, data)

    def format_TAP_msg(self, result, name, desc="", data=None):
        return self.translate_msg[result](name, desc, data)


if __name__ == '__main__':
    pass
